(function() {
	/********************************
	 * Accelerometer
	 * 加速度センサーの情報を取得する
	 ********************************/

	/*
	 * 変数の宣言
	 */
	var accelerationWatchID;	// 加速度監視停止用のID

	/*
	 * 現在の加速度センサー値を取得
	 */
	getCurrentAcceleration = function() {
		applican.accelerometer.getCurrentAcceleration(currentAccelerationSuccess, currentAccelerometerError);
	};

	/*
	 * getCurrentAccelerationにより加速度センサー値の取得に成功時のコールバック
	 * res.x : Number X軸方向の加速度
	 * res.y : Number Y軸方向の加速度
	 * res.z : Number Z軸方向の加速度
	 */
	currentAccelerationSuccess = function(res) {
		// 加速度情報を出力
		var dump = "現在の加速度を取得しました\n";
		dump    += "X軸方向の加速度：" + res.x + "\n";
		dump    += "Y軸方向の加速度：" + res.y + "\n";
		dump    += "Z軸方向の加速度：" + res.z;

		document.getElementById("dumpAreaAcceleration").value = dump;
	};

	/*
	 * getCurrentAccelerationにより加速度センサー値の取得に失敗時のコールバック
	 */
	currentAccelerometerError = function() {
		var dump = "現在の加速度を取得失敗しました\n";
		document.getElementById("dumpAreaAcceleration").value = dump;
	};

	/*
	 * 加速度を一定の時間間隔で取得
	 * frequency : Number 監視する間隔を指定(ミリ秒)
	 */
	watchAcceleration = function() {
		// ポップアップ画面を表示
		document.getElementById("ballPopup").style.display = "block";
		// ポップアップ画面でボールの位置を固定にする
		document.getElementById("gravityBall").style.position = "fixed";
		
		var options = { frequency: 100 };
		accelerationWatchID = applican.accelerometer.watchAcceleration(watchAccelerationSuccess, watchAccelerationError, options);
	};

	/*
	 * watchAccelerationにより加速度センサー値の取得に成功時のコールバック
	 * res.x X軸方向の加速度
	 * res.y Y軸方向の加速度
	 * res.z Z軸方向の加速度
	 */
	watchAccelerationSuccess = function(res) {
		setBallPosition(res);

		// 加速度情報を出力
		var dump = "加速度を取得しました\n";
		dump    += "X軸方向の加速度：" + res.x + "\n";
		dump    += "Y軸方向の加速度：" + res.y + "\n";
		dump    += "Z軸方向の加速度：" + res.z;
		document.getElementById("dumpAreaAcceleration").value = dump;
	};

	/*
	 * watchAccelerationにより加速度センサー値の取得に失敗時のコールバック
	 */
	watchAccelerationError = function() {
		var dump = "加速度を取得失敗しました\n";
		document.getElementById("dumpAreaAcceleration").value = dump;
	};

	/*
	 * 加速度の監視を停止する
	 */
	clearWatchAcceleration = function() {
		applican.accelerometer.clearWatch(accelerationWatchID);
		// ポップアップDIVを閉じる
		document.getElementById("ballPopup").style.display = "none";

		// ボールの位置と大きさを復元
		document.getElementById("gravityBall").style.position = "absolute";
		document.getElementById("gravityBall").style.width    = 64 + "px";
		document.getElementById("gravityBall").style.height   = 64 + "px";
		document.getElementById("gravityBall").style.top      = "22%";
		document.getElementById("gravityBall").style.left     = "42%";
		
		alert("加速度の監視を終了しました");
	};

	/*
	 * ボールの位置を設定する
	 */
	setBallPosition = function(res) {
		// X軸の位置
		var offsetLeft       = res.x * res.x * 1000 + document.body.offsetWidth / 2;
		// Y軸の位置
		var offsetTop        = res.y * res.y * 1000;
		// 各辺縁の座標の校正
		var correctionRight  = -65;
		var correctionTop    = 6;
		var correctionBottom = 304;

		// 地面に垂直の方向に移動する場合、ボールの大きさを計算する(元のサイズ：64×64)
		document.getElementById("gravityBall").style.width  = Math.abs(res.z) * 64 + "px";
		document.getElementById("gravityBall").style.height = Math.abs(res.z) * 64 + "px";

		if (res.x <= 0 && offsetLeft > document.body.offsetWidth) {
			// 左へ傾斜する場合、ディスプレイ範囲を超過したの時は、X座標を左側の境界値にする
			document.getElementById("gravityBall").style.left = 0 + "px";
		} else if (res.x > 0 && offsetLeft > document.body.offsetWidth + correctionRight) {
			// 右へ傾斜する場合、ディスプレイ範囲を超過したの時は、X座標を右側の境界値にする
			document.getElementById("gravityBall").style.left = document.body.offsetWidth + correctionRight + "px";
		} else if (res.x <= 0) {
			// 左へ傾斜する場合、ディスプレイ範囲内の時は、X座標を計算する
			document.getElementById("gravityBall").style.left = document.body.offsetWidth - offsetLeft + "px";
		} else if (res.x > 0) {
			// 右へ傾斜する場合、ディスプレイ範囲内の時は、X座標を計算する
			document.getElementById("gravityBall").style.left = offsetLeft + "px";
		}

		if (res.y <= 0 && offsetTop <= correctionBottom) {
			// 下へ傾斜する場合、ディスプレイ範囲内の時は、Y座標を計算する
			document.getElementById("gravityBall").style.top = offsetTop + correctionTop + "px";
		} else if (res.y <= 0 && offsetTop > correctionBottom) {
			// 下へ傾斜する場合、ディスプレイ範囲を超過したの時は、Y座標を下側の境界値にする
			document.getElementById("gravityBall").style.top = correctionBottom + "px";
		} else if (res.y > 0) {
			// 上へ傾斜する場合、Y座標を上側の境界値にする
			document.getElementById("gravityBall").style.top = correctionTop + "px";
		}
	};

	/********************* イベント登録 *********************/
	document.addEventListener("deviceready", function() {
		//「現在の加速度を取得」ボタン押下時の処理
		document.getElementById("getAcceleBtn").addEventListener("click", getCurrentAcceleration, false);
		//「加速度を一定の時間間隔で取得」ボタン押下時の処理
		document.getElementById("watchAcceleBtn").addEventListener("click", watchAcceleration, false);
		//「加速度の監視を停止」ボタン押下時の処理
		document.getElementById("clearWatchAcceleBtn").addEventListener("click", clearWatchAcceleration, false);
	}, false);
})();
